<!DOCTYPE TS><TS>
<context>
    <name>ChooseFileRadioButton</name>
    <message>
        <source>Choose</source>
        <translation>Choisir</translation>
    </message>
</context>
<context>
    <name>ConfigConnection</name>
    <message>
        <source>Start server</source>
        <translation>Démarrer le serveur</translation>
    </message>
    <message>
        <source>Host : </source>
        <translation>Hôte:</translation>
    </message>
    <message>
        <source>Port : </source>
        <translation>Port:</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Démarrer</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Quitter</translation>
    </message>
</context>
<context>
    <name>DisplayScenarii</name>
    <message>
        <source>Size</source>
        <translation>Taille</translation>
    </message>
    <message>
        <source>Players</source>
        <translation>Joueurs</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
</context>
<context>
    <name>DisplayScenariiDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
</context>
<context>
    <name>DisplayScenarioDescription</name>
    <message>
        <source>Name: %1</source>
        <translation>Nom : %1</translation>
    </message>
    <message>
        <source>Player(s): %1</source>
        <translation>Joueur(s) : %1</translation>
    </message>
    <message>
        <source>Size: %1x%2</source>
        <translation>Taille : %1x%2</translation>
    </message>
    <message>
        <source>Description: %1</source>
        <translation>Description : %1</translation>
    </message>
    <message>
        <source>Name: </source>
        <translation>Nom :</translation>
    </message>
    <message>
        <source>Player(s): </source>
        <translation>Joueur(s) :</translation>
    </message>
    <message>
        <source>Size: </source>
        <translation>Taille :</translation>
    </message>
    <message>
        <source>Description: </source>
        <translation>Description : </translation>
    </message>
</context>
<context>
    <name>Engine</name>
    <message>
        <source>Error with scenario</source>
        <translation>Erreur dans le scénario</translation>
    </message>
    <message>
        <source>Wrong number of connected players</source>
        <translation>Nombre de joueurs connectés incorrect</translation>
    </message>
    <message>
        <source>You have no place for recruiting new creatures</source>
        <translation>Vous n&apos;avez plus de place pour de nouvelles créatures</translation>
    </message>
    <message>
        <source>You have not enough resources for recruiting this creatures</source>
        <translation>Vous n&apos;avez pas assez de ressources pour recruter ces créatures</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Unknown</source>
        <translation>Inconnu</translation>
    </message>
</context>
<context>
    <name>ServerInterface</name>
    <message>
        <source>Attal - Lords of Doom (Server)</source>
        <translation>Serveur pour &apos;Attal - Lords of Doom&apos;</translation>
    </message>
    <message>
        <source>Server error</source>
        <translation>Erreur du serveur</translation>
    </message>
    <message>
        <source>Could not listen for sockets.</source>
        <translation>Impossible d&apos;écouter les sockets.
</translation>
    </message>
    <message>
        <source>Try again</source>
        <translation>Essayez à nouveau</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Quitter</translation>
    </message>
    <message>
        <source>Status Bar</source>
        <translation>Barre de statut</translation>
    </message>
    <message>
        <source>Load Game</source>
        <translation type="obsolete">Charger un jeu</translation>
    </message>
    <message>
        <source>Save Game</source>
        <translation type="obsolete">Sauver le jeu</translation>
    </message>
    <message>
        <source>End Game</source>
        <translation type="obsolete">Finir le jeu</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Fichier</translation>
    </message>
    <message>
        <source>Can&apos;t load theme</source>
        <translation>Impossible de charger le thème</translation>
    </message>
    <message>
        <source>Theme </source>
        <translation>Thème</translation>
    </message>
    <message>
        <source> has not been loaded successfully</source>
        <translation>n&apos;a pas été chargé correctement</translation>
    </message>
    <message>
        <source>Load Scenario</source>
        <translation type="obsolete">Charger Scenario</translation>
    </message>
    <message>
        <source>Load Campaign</source>
        <translation type="obsolete">Charger Campagne</translation>
    </message>
    <message>
        <source>Load scenario</source>
        <translation>Charger scenario</translation>
    </message>
    <message>
        <source>Load campaign</source>
        <translation>Charger campagne</translation>
    </message>
    <message>
        <source>Load game</source>
        <translation>Charger jeu</translation>
    </message>
    <message>
        <source>Save game</source>
        <translation>Sauver jeu</translation>
    </message>
    <message>
        <source>End game</source>
        <translation>Fin du jeu</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Quitter</translation>
    </message>
    <message>
        <source>Fill with AI</source>
        <translation>Compléter avec des IA</translation>
    </message>
    <message>
        <source>Add AI player</source>
        <translation>Ajouter un joueur IA</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Jeu</translation>
    </message>
</context>
<context>
    <name>ServerWidget</name>
    <message>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adresse</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Démarrer</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Sauver</translation>
    </message>
    <message>
        <source>End</source>
        <translation>Finir</translation>
    </message>
</context>
</TS>
